CompleteEnv

Struct CompleteEnv 

pub struct CompleteEnv<'s, F> { /* private fields */ }
Available on crate feature unstable-dynamic only.
Environment-activated completions for your CLI

Benefits over a CLI completion argument or subcommand

  • Performance: we don’t need to generate clap::Command twice or parse arguments
  • Flexibility: there is no concern over it interfering with other CLI logic

Warning: stdout should not be written to before CompleteEnv::complete has had a chance to run.

Examples

fn cli() -> clap::Command {
    // ...
}

CompleteEnv::with_factory(cli)
    .complete()

// ... rest of application logic

Implementations

Source

impl<'s, F: Fn() -> Command> CompleteEnv<'s, F>

pub fn with_factory(factory: F) -> Self

Complete a clap::Command

Example

Builder:

fn cli() -> clap::Command {
    // ...
}

CompleteEnv::with_factory(cli)
    .complete()

// ... rest of application logic

Derive:

use clap::CommandFactory as _;

#[derive(Debug, Parser)]
struct Cli {
    custom: Option<String>,
}

CompleteEnv::with_factory(Cli::command)
    .complete()

// ... rest of application logic
pub fn var(self, var: &'static str) -> Self

Override the environment variable used for enabling completions

pub fn bin(self, bin: impl Into<String>) -> Self

Override the name of the binary to complete

Default: Command::get_bin_name

pub fn completer(self, completer: impl Into<String>) -> Self

Override the binary to call to get completions

Default: args_os()[0]

pub fn shells(self, shells: Shells<'s>) -> Self

Override the shells supported for completions

Source

impl<'s, F: Fn() -> Command> CompleteEnv<'s, F>

pub fn complete(self)

Process the completion request and exit

Warning: stdout should not be written to before this has had a chance to run.

pub fn try_complete( self, args: impl IntoIterator<Item = impl Into<OsString>>, current_dir: Option<&Path>, ) -> Result<bool>

Process the completion request

Warning: stdout should not be written to before or after this has run.

Returns true if a command was completed and false if this is a regular run of your application